@@ -20,6 +20,7 @@ from CIDAN.LSSC.functions.pickle_funcs import *
 from CIDAN.LSSC.functions.progress_bar import printProgressBarFilter
 from CIDAN.LSSC.functions.roi_extraction import roi_extract_image, combine_rois
 from CIDAN.LSSC.functions.roi_filter import filterRoiList
+from CIDAN.LSSC.functions.spatial_footprint import classify_components_ep
 from CIDAN.LSSC.process_data import process_data
 from CIDAN.TimeTrace.deltaFOverF import calculateDeltaFOverF
 from CIDAN.TimeTrace.mean import calculateMeanTrace
@@ -1216,7 +1217,13 @@ class DataHandler:
         return final_roi
 
     def calculate_statistics(self):
+        statistics = [False for x in range(len(self.rois))]
+        A = np.zeros([self.edge_roi_image_flat.shape[0], len(self.rois)], dtype=int)
+        for num, roi in enumerate(self.rois):
+            A[roi, num] = 1
+        rval, significant_samples = classify_components_ep(self.dataset_trials_filtered_loaded, A, np.vstack([self.get_time_trace(x+1) for x in range(len(self.rois))]))
         pass
+
     def export(self):
         temp_type = self.time_trace_params["time_trace_type"]
         for time_type in ["Mean", "DeltaF Over F"]:
@@ -1224,7 +1231,8 @@ class DataHandler:
                 self.time_trace_params["denoise"] = denoise
                 self.time_trace_params["time_trace_type"] = time_type
                 self.calculate_time_traces()
-        self.calculate_statistics()
+                if time_type=="Mean" and denoise:
+                    self.calculate_statistics()
         self.time_trace_params["time_trace_type"] = temp_type
         self.save_rois(self.rois)
         roi_save_object = []
@@ -1239,9 +1247,37 @@ class DataHandler:
                 cords = spatial_box.convert_1d_to_2d(roi)
             curr_roi = {"id": num, "coordinates": cords}
             roi_save_object.append(curr_roi)
+
         with open(os.path.join(self.save_dir_path, "roi_list.json"), "w") as f:
             json.dump(roi_save_object, f)
+        shape = self.edge_roi_image_flat.shape
+        roi_image_blob = self.pixel_with_rois_color_flat
+        roi_image_outline = np.hstack(
+            [self.edge_roi_image_flat,
+             np.zeros(shape),
+             np.zeros(shape)])
+        max_image = np.reshape(np.max([self.max_images[x] for x in self._trials_loaded_indices],axis=0),(-1,1))
+        roi_image_blob_w_background =roi_image_blob+np.hstack(
+                [max_image, max_image,max_image])/max_image.max()*255
+        roi_image_outline_w_background = roi_image_outline +np.hstack(
+                [max_image, max_image,max_image])/max_image.max()*255
+        self.save_image(roi_image_blob, os.path.join(self.save_dir_path, "roi_blob.png"))
+        self.save_image(roi_image_outline,
+                        os.path.join(self.save_dir_path, "roi_outline.png"))
+        self.save_image(roi_image_outline_w_background,
+                        os.path.join(self.save_dir_path, "roi_outline_background.png"))
+        self.save_image(roi_image_blob_w_background,
+                        os.path.join(self.save_dir_path, "roi_blob_background.png"))
+        self.save_image(np.hstack(
+                [max_image, max_image,max_image]),
+                        os.path.join(self.save_dir_path, "max.png"))
 
+    def save_image(self, image, path):
+        img = Image.fromarray(
+            (np.reshape(image - image.min(),
+                        (self.shape[0], self.shape[1], 3)) / (
+                         image.max() - image.min()) * 255).astype("uint8"))
+        img.save(path)
     def delete_roi_vars(self):
         self.rois = []
         self.rois_loaded = False
