@@ -19,8 +19,16 @@ class ROIListModule(QFrame):
         self.roi_tab = roi_tab
         self.color_list = data_handler.color_list
         self.list = QListView()
+
         self.setStyleSheet("QListView::item { border-bottom: 1px solid rgb(50, 65, " +
-                           "75); }")
+                           "75); } "+"""QListView::item::pressed,
+ {
+  background-color: #19232D;
+  border: 1px solid #32414B;
+  color: #F0F0F0;
+  gridline-color: #32414B;
+  border-radius: 4px;
+}""")
         self.top_labels_layout = QHBoxLayout()
         label1 = QLabel(text="ROI Selected")
         label1.setMaximumWidth(100)
@@ -48,6 +56,7 @@ class ROIListModule(QFrame):
         self.list.setCurrentIndex(self.model.index(int(num - 1), 0))
         self.roi_time_check_list[num - 1] = not self.roi_time_check_list[num - 1]
         self.roi_item_list[num - 1].select_check_box()
+        # self.roi_module_list[num-1].
         if self.display_time:
             self.roi_item_list[num - 1].select_time_check_box()
 
@@ -56,6 +65,7 @@ class ROIListModule(QFrame):
         for x in range(self.model.rowCount()):
             self.model.removeRow(0)
         self.roi_item_list = []
+        self.roi_module_list =[]
         for num in range(len(self.roi_list)):
             item = ROIItemWidget(self.roi_tab,
                                  self.color_list[num % len(self.color_list)], self,
@@ -63,8 +73,10 @@ class ROIListModule(QFrame):
                                  )
             item1 = ROIItemModule(self.color_list[num % len(self.color_list)], num + 1,
                                   self.roi_tab)
+            item1.setSelectable(False)
             self.roi_item_list.append(item)
             self.model.appendRow(item1)
+            self.roi_module_list.append(item1)
             self.list.setIndexWidget(item1.index(), item)
         self.roi_time_check_list = [False] * len(self.roi_item_list)
         if hasattr(self.roi_tab, "tab_selector_roi"):
