@@ -1,3 +1,4 @@
+from qtpy import QtCore
 from qtpy.QtWidgets import *
 
 from CIDAN.GUI.Inputs.BoolInput import BoolInput
@@ -30,7 +31,7 @@ class SettingBlockModule(QFrame):
         # Type options are int, float, bool, and str
         for input in input_list:
             self.layout.addWidget(input)
-
+        # self.setMaximumWidth(300)
         self.setLayout(self.layout)
 
 
